#[non_exhaustive]pub enum CodecError {
Io(Error),
Protocol(ProtocolError),
PacketTooLarge {
size: usize,
max: usize,
},
IncompletePacket {
needed: usize,
},
InvalidHeader,
ConnectionClosed,
Encoding(String),
Decoding(String),
}Expand description
Errors that can occur during packet encoding/decoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
IO error during read/write operations.
Protocol(ProtocolError)
Protocol-level error from tds-protocol.
PacketTooLarge
Packet too large.
IncompletePacket
Incomplete packet data.
InvalidHeader
Invalid packet header.
ConnectionClosed
Connection closed unexpectedly.
Encoding(String)
Encoding error.
Decoding(String)
Decoding error.
Implementations
Sourceimpl CodecError
impl CodecError
Sourcepub fn is_transient(&self) -> bool
pub fn is_transient(&self) -> bool
Check if this error is transient and may succeed on retry.
IO errors and connection closures are typically transient. Protocol, encoding, and header errors are terminal.
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Check if this error is terminal and will never succeed on retry.